@@ -26,7 +26,7 @@ Win32::OLE->Initialize(Win32::OLE::COINIT_OLEINITIALIZE);
 #Win32::OLE->Option('_Unique' => 1);
 #@ISA = qw(Win32::OLE);
 
-my $VERSION = "0.0.0.024";
+my $VERSION = "0.025";
 my $DEBUG = 1;
 
 #CONSTANTS
@@ -207,6 +207,9 @@ sub GetVersion {
     $return_struct{ver}= $1;
     $return_struct{build}= $2;
     $return_struct{sp}= $3;
+    #if ($return_struct{sp} < 2 && $return_struct{ver} eq "6.0") {
+    #  _DebugComment("It's possible that some of the E2K permissions functions will fail due to an incompatible E2K Service Pack level (please see the HTML docs for details)\n")
+    #}
     if (scalar(@_) == 2) {
       %{$_[1]} = %return_struct;
     } else {
@@ -732,13 +735,7 @@ sub _E2KCreateMailbox {
     _ReportArgError("CreateMailbox [E2K] (".scalar(@_));
     return 0;
   }
-  if ($nt_pdc =~ /^\\\\.*/) {
-    $nt_pdc =~ /^\\\\(.*)/;
-    $pdc = $1;
-  } else {
-    $pdc = $nt_pdc;
-  }
- 
+  _StripBackslashes($nt_pdc,$pdc); 
   my $user_dist_name;
   if (!AdodbSearch($pdc,"(samAccountName=$mailbox_alias_name)","samAccountName,distinguishedName",$user_dist_name)) {
     _DebugComment("Error querying distinguished name for user in CreateMailbox (E2K)\n");
@@ -821,6 +818,17 @@ sub GetDistinguishedName {
   }
 }
 
+sub _StripBackslashes {
+  my $nt_pdc = $_[0];
+  if ($nt_pdc =~ /^\\\\(.*)/) {
+    $_[1] = $1;
+    return 1;
+  } else {
+    $_[1] = $nt_pdc;
+    return 1;
+  }
+}
+
 sub GetMailbox {
   my $error_num;
   my $error_name;
@@ -837,8 +845,6 @@ sub GetMailbox {
   }
   bless $provider,"Win32::Exchange";
   if ($type eq "IPerson") {
-    _DebugComment("Not functional at this time.\nI don't know that this is a feasible sub since the object you want to look at is an User Account.\n");
-    return 0;
     #IPerson returns for CDO.Person (E2K)
     if ($mbx = _E2KGetMailbox(@_)) {
       return $mbx;
@@ -905,68 +911,53 @@ sub _E55GetMailbox {
   return bless $mailbox,"Win32::Exchange";
 }
 
-#sub _E2KGetMailbox {
-#  my $error_num;
-#  my $error_name;
-#  my $provider;
-#  my $info_store_server;
-#  my $pdc;
-#  my $nt_pdc;
-#  my $mailbox_alias_name;
-#  my $mail_domain;
-#  my $storage_group;
-#  my $mb_store;
-#  if (scalar(@_) >4) {
-#    $provider = $_[0];
-#    $info_store_server = $_[1];
-#    $nt_pdc = $_[2];
-#    $mailbox_alias_name = $_[3];
-#    if (scalar(@_) == 5) {
-#      #placeholder..
-#    } elsif (scalar(@_) == 7) {
-#      $storage_group = $_[4];
-#      $mb_store = $_[5];
-#    } else {
-#      _ReportArgError("GetMailbox [E2K]",scalar(@_));
-#      return 0;
-#    }
-#  } else {
-#    _ReportArgError("GetMailbox [E2K]",scalar(@_));
-#    return 0;
-#  }
-#  if ($nt_pdc =~ /^\\\\.*/) {
-#    $nt_pdc =~ /^\\\\(.*)/;
-#    $pdc = $1;
-#  } else {
-#    $pdc = $nt_pdc;
-#  }
-#
-#  my $user_dist_name;
-#  if (!AdodbSearch($pdc,"(samAccountName=$mailbox_alias_name)","samAccountName,distinguishedName",$user_dist_name)) {
-#    _DebugComment("Error querying distinguished name for user in CreateMailbox (E2K)\n");
-#    return 0;
-#  }
-#
-#  bless $provider,"Win32::OLE";
-#  my $user_account = $provider->DataSource->Open("LDAP://$pdc/$user_dist_name");
-#  if (!_ErrorCheck(Win32::OLE->LastError(),"0x00000000",$error_num,$error_name)) {
-#    _DebugComment("Failed opening NT user account for new mailbox creation on $pdc ($error_num)\n");
-#    bless $provider,"Win32::Exchange";
-#    return 0;
-#  }
-#  my $info_store = $provider->GetInterface( "IMailboxStore");
-#  if (!_ErrorCheck(Win32::OLE->LastError(),"0x00000000",$error_num,$error_name)) {
-#    _DebugComment("Failed opening mailbox interface on $pdc ($error_num)\n");
-#    if ($error_num eq "0x80004002") {
-#      _DebugComment("Error:  No such interface supported.\n  Note:  Make sure you have the Exchange System Manager loaded on this system\n");
-#    }
-#    bless $provider,"Win32::Exchange";
-#    return 0;
-#  }
-#  #this isn't really a mailbox, but the underlying object that you need to do manipulations on.
-#  #this isn't tested much though.  Sorry.
-#  return $user_account;
-#}
+sub _E2KGetMailbox {
+  my $error_num;
+  my $error_name;
+  my $provider;
+  my $mailbox_alias_name;
+  my $nt_dc;
+  my $dc;
+  if (scalar(@_) == 3) {
+    $provider = $_[0];
+    $nt_dc = $_[1];
+    $mailbox_alias_name = $_[2];
+  } else {
+    _ReportArgError("GetMailbox [E2K]",scalar(@_));
+    return 0;
+  }
+  _StripBackslashes ($nt_dc,$dc);
+  
+  my $user_dist_name;
+  if (!AdodbSearch($dc,"(samAccountName=$mailbox_alias_name)","samAccountName,distinguishedName",$user_dist_name)) {
+    _DebugComment("Error querying distinguished name for user in GetMailbox (E2K)\n");
+    return 0;
+  }
+
+  bless $provider,"Win32::OLE";
+  $provider->DataSource->Open("LDAP://$dc/$user_dist_name");
+  if (!_ErrorCheck(Win32::OLE->LastError(),"0x00000000",$error_num,$error_name)) {
+    _DebugComment("Failed opening AD user account for mailbox retrieval on $dc ($error_num)\n");
+    bless $provider,"Win32::Exchange";
+    return 0;
+  }
+  my $user_obj_path = $provider->DataSource->{SourceURL};
+  my $user_obj = Win32::OLE->GetObject($user_obj_path);
+  if (!_ErrorCheck(Win32::OLE->LastError(),"0x00000000",$error_num,$error_name)) {
+    _DebugComment("Failed opening SourceURL for GetMailbox ($error_num)\n");
+    return 0;
+  }
+  if ($user_obj->{homeMDB} eq "") {
+    #Win32::OLE->LastError("0x80072030"); #I hope this works
+    _DebugComment("Error performing GetMailbox..  mailbox does not exist ($error_num)\n");
+    bless $provider,"Win32::Exchange";
+    return 0;
+  } else {
+    $provider->DataSource->Save();
+    bless $provider,"Win32::Exchange";
+    return $provider;
+  }
+}
 
 sub SetAttributes {
   my $error_num;
